// Solution by David van Brackle, modified by Kip Irvine to
// handle multiple test cases.

import java.io.*;
import java.util.*;

public class ClassyProblem
{
    public Scanner sc;
    public PrintStream ps;
    
    /**
     * This represents a person, their rank, and their key, 
     * which is how we'll sort them.
     */
    public class Person implements Comparable<Person>
    {
        public String name;
        public String rank[];
        public String key;
        
        public Person( String name, String rank[] )
        {
            this.name = name;
            this.rank = rank;
            this.key = "";
        }

        public int compareTo( Person p )
        {
            return key.compareTo( p.key );
        }
        
        public void buildKey( int k )
        {
            // For all of their rank words, give them:
            //  'a' for "upper"
            //  'b' for "middle"
            //  'c' for "lower"
            // Start at the end - it's the one that dominates - and work back to the start.
            for( int i = rank.length-2; i>=0; --i  )
            {
                String subrank = rank[i];
                if( subrank.equals( "upper" ) ) key += 'a';
                else if( subrank.equals( "middle" ) ) key += 'b';
                else if( subrank.equals( "lower" ) ) key += 'c';
            }
            
            // If this one is shorter than the longest one,
            // fill in with 'b' for "middle".
            for( int i=rank.length; i<k; i++ )
            {
                key += 'b';
            }
            
            // Add the name to the end of the key,
            // so that the sort will be correct if
            // two people (Persons?) have the same class.
            key += name.toLowerCase();
        }
    }
        
    public void oneTestCase() throws Exception
    {        
        int n = sc.nextInt();
        sc.nextLine();
        Person people[] = new Person[n];
        int most = 0;
        for( int i=0; i<n; i++ )
        {
            String line = sc.nextLine();
            
            // Split at the colon
            int p = line.indexOf( ':' );
            
            // The Name is everything up to the colon
            String name = line.substring( 0, p );
            
            // The Rank is everything after the colon, split at whitespace.
            String rank[] = line.substring( p+1 ).trim().split( "\\s+" );
            
            // Create a Person
            people[i] = new Person( name, rank );
            
            // Keep track of the most specifiers.
            most = Math.max( most, rank.length );
        }
        
        // Compute a Key for each person
        for( Person person : people )
        {
            person.buildKey( most );
        }
        
        // Sort by Key
        Arrays.sort( people );
        
        // Print the results
        for( Person person : people )
        {
            ps.println( person.name );
        }
        System.out.println();   // blank line after each test case (even the last one)
    }
    
    void doit() throws Exception {
        sc = new Scanner( System.in );
        ps = System.out;
        
        int numTestCases = sc.nextInt();
        for(int i=0; i < numTestCases; i++)
        	oneTestCase();    	
    }
    
    public static void main( String[] args ) throws Exception
    {
        new ClassyProblem().doit();        
    }   
}
