// GoSightseeing_easy.cpp

// Giuseppe Vietri's, dynamic programming solution to the Go Sightseeing problem.

#include <bits/stdc++.h>
using namespace std;

#define MEM(arr,val)memset((arr),(val), sizeof (arr))
#define PI (acos(0)*2.0)
#define FASTER ios_base::sync_with_stdio(false); cin.tie(NULL); cout.tie(NULL)
#define ALL(v)v.begin(),v.end()
#define PB(v)push_back(v)

typedef long long ll;
typedef pair<int,int> ii;
typedef vector<int> vi;
typedef vector<ii> vii;

ll gcd(ll a,ll b){return b == 0 ? a : gcd(b,a%b);}
ll lcm(ll a,ll b){return a*(b/gcd(a,b));}

/**
 * __builtin_popcount(int d) // count bits
 * __builtin_popcountll(long long d)
 * strtol(s, &end, base); // convert base number
 */
//----------------------------------------------------------------------//
#define MAXN 3000
#define IMPOSSIBLE 3000

ll N,Ts, Tf;
ll start[MAXN], frequency[MAXN],duration[MAXN];
int dp[MAXN][MAXN];

/**
 * Returns the earliest time you can reach city i+1, if
 * you start waiting at time t in city i
 */
ll nextBus(int i, ll t){

	ll s = start[i];
	ll f = frequency[i];
	ll d = duration[i];

	// If you start waiting before the bus start time
	if(s >= t)return s + d;

	// Special case
	if( ((t-s) % f) == 0)
		return t + d;

	// Get the earliest departing bus after time t. plus the
	// duration to get to the next city
	return t + (f - ((t-s) % f)) + d;
}


/**
 * solv(i, t) = max number of cities you can go sightseeing such that you start at
 * city i and time t
 */
int solv(int i, int t){

	int &ret = dp[i][t];

	// If you reach the last city
	if(i == N-1){
		if(t > Tf)
			ret = IMPOSSIBLE;
		else
			ret = 0;
	}

	// A value of -1 indicates that we have not solved this particular
	// case before. Any other value lets us return immediately with the
	// memoized value.
	
	if(ret == -1){

		// Case 1: if you do not Go sightseeing in city i
		int noSightseeing = solv(i+1, nextBus(i,t));

		// Case 2: if pyou Go sightseeing in city i
		int goSightseeing = solv(i+1, nextBus(i,t+Ts));


		/*
		 * If solv(.) returns IMPOSSIBLE that means that it cannot reach
		 * the last city (N-1) in before the time Tf
		 */
		if(noSightseeing == IMPOSSIBLE && goSightseeing == IMPOSSIBLE)
			ret = IMPOSSIBLE;
		else if(noSightseeing == IMPOSSIBLE){
			ret = goSightseeing + 1;
		}else if(goSightseeing == IMPOSSIBLE){
			ret = noSightseeing;
		}else{
			// If both options are reachable then return the path that maximizes the number
			// of cities that can go sightseeing
			ret = max(noSightseeing, goSightseeing+1);
		}
	}
	return ret;
}

int main(){
	FASTER;
	int T;
	cin >> T;
	int Case = 1;
	while(T--){
		cin >> N >> Ts >> Tf;

		for (int i = 0; i < N-1; ++i) {
			cin >> start[i] >> frequency[i] >> duration[i];
		}

		memset(dp, -1, sizeof dp);

		int maxSightseeingCities = solv(0,0);


		cout << "Case #" << (Case++)<<": ";
		if(maxSightseeingCities == IMPOSSIBLE){
			cout << "IMPOSSIBLE\n";
		}else{
			cout << maxSightseeingCities << endl;
		}
	}

	return 0;
}
