// Mordred.java
// Solution to Mordred's Treasure problem
// By Kip Irvine

import java.util.LinkedList;
import java.util.List;
import java.util.Queue;
import java.util.Scanner;

public class Mordred {

	private char[][] data;
	boolean[][] visited;
	
	private int startRow;
	private int startCol;
	public int treasureRow;
	public int treasureCol;
	Scanner in;
	
	int rows;
	int columns;
	
	final char Empty = ' ';
	
		class Square {
			int row, col, dist;
			
			Square(int row, int col, int dist) {
				this.row = row;
				this.col = col;
				this.dist = dist;
			}
		} // class
	
		
	boolean isBlocked( int row, int column )
	{
		// hit a wall?
		return row < 0 || column < 0 || row >= rows || column >= columns 		
					|| data[row][column] == 'X';
	}
		
	List<Square> findNeighbors(Square curr) {
		
		List<Square> temp = new LinkedList<>();
		int r, c;
		
		r = curr.row-1;
		c = curr.col;
		if( !isBlocked( r, c))
			temp.add(new Square(r,c, curr.dist + 1));

		r = curr.row+1;
		c = curr.col;
		if( !isBlocked( r, c))
			temp.add(new Square(r,c, curr.dist + 1));

		r = curr.row;
		c = curr.col-1;
		if( !isBlocked( r, c))
			temp.add(new Square(r,c, curr.dist + 1));

		r = curr.row;
		c = curr.col+1;
		if( !isBlocked( r, c))
			temp.add(new Square(r,c, curr.dist + 1));
				
		return temp;
	}
	
	
	/**
	 * BFS Search the adjacent cells, using a depth-first search approach
	 * Returns the minimum unweighted path length.
	 */
	public int searchBfs( int row, int col )
	{		
		visited = new boolean[rows][columns];
		
		Queue<Square> queue = new LinkedList<>();		
		queue.add(new Square(row,col,0));  // start of search
		
		while( !queue.isEmpty())  {
			Square u = queue.poll();
			visited[u.row][u.col] = true;
			
			List<Square> adj = findNeighbors(u);
			
			for( Square sq : adj) {
				if( data[sq.row][sq.col] == 'T' ) 
					return sq.dist;
				else if( !visited[sq.row][sq.col] ) {
					queue.add(sq);					
				}				
			} // for			
		}  // while
		
		return Integer.MAX_VALUE;  // unable to find the treasure (highly unlikely)
	}
	
	private void loadTheMap()
	{
		for(int row = 0; row < data.length; row++ )
		{
			char[] input = in.nextLine().toCharArray();
			for(int col = 0; col < data[row].length; col++ )
			{				
				data[row][col] = input[col];
				if( input[col] == 'S' ) {
					startRow = row;
					startCol = col;
				}
			}
		}	//for
	}  // loadTheMap	
	
	void start() {
		in = new Scanner( System.in );	
		int numTestCases = in.nextInt();
		in.nextLine();
		
		for(int testCase = 0; testCase < numTestCases; testCase++)
		{		
			rows = in.nextInt();
			columns = in.nextInt();
			data = new char[rows][columns];
			in.nextLine();		
			loadTheMap();
			
			// find each start(S) character and launch a search.
			// keep track of the shortest unweighted path			

			int minPath = Integer.MAX_VALUE;
			for(int i=0; i < rows; i++) {
				for(int j=0; j < columns; j++) {
					if( data[i][j] == 'S') {
						int pathLen = searchBfs(i, j);
						minPath = Math.min(minPath,  pathLen);
					}
				}
			} 
			// print the results as a single integer
			if( minPath == Integer.MAX_VALUE)
				System.out.println(-1);
			else
				System.out.println( minPath );
			
		}  // for each test case	
		
	} // start method
	
	public static void main(String[] args) {
		new Mordred().start();		
	}  // main
} // class

