// The Tourist Guide (uva 10099 )

// Solution by Irvine, accepted by UVA.
// Bottleneck shortest path problem (Floyd-Warshall works).
// Note: The guide must ride the bus with his passengers. Also, the source and
// destination might be the same. 
// In the sample, data, the max capacity of 1-2-4-7 is 25, so 99 passengers
// require 5 trips, containing  24 + 24 + 24 + 24 + 3 = 99

#include<iostream>
#include<cstdio>
#include<vector>
#include <algorithm>
using namespace std;

void findPaths(int);

class edge {
public:
	int target;
	int weight;
	edge(int t, int w)
	{ target = t;  weight = w; }
};

int cities;
vector< vector<double> > G;

int main()
{
	int cities;
	int roads;
	int source, target, people;
	int scenario = 1;

	scanf("%d %d", &cities, &roads);
	while( cities > 0 )
	{
		G.resize(cities+1);
		for(int i = 1; i <= cities; i++) 
			for(int j = 0; j <= cities; j++)
				G[i].push_back( 0 );    // normally, this is INT_MAX (in limits.h)

		for(int i = 0; i < roads; i++)
		{
			int a, v, wt;
			scanf("%d %d %d", &a, &v, &wt);
			G[a][v] = G[v][a] = wt;
		}
		scanf("%d %d %d", &source, &target, &people);

		// call Floyd-Warshall
		findPaths(cities);
		int capacity = (int) G[source][target] - 1;
		//printf("path from %d to %d has max capacity %d\n", source, target, (int) G[source][target]);		
		
		int k = people / capacity;
		if( people % capacity > 0 )
			k++;
		
		printf("Scenario #%d\n", scenario);
		if( source == target )
			k = 0;
		
		printf("Minimum Number of Trips = %d\n\n", k);		
		
		scanf("%d %d", &cities, &roads);
		G.clear();
		scenario++;
	}

	return 0;
}

void findPaths(int n)			//n is the number of edges
// Modified Floyd-warshall: instead of finding the shortest path,
// we find the path with the greatest overall capacity.
// (Along each path, the minimum value edge determines its capacity, like network flow.)
	{
		for (int k = 1; k <= n; k++)
			for (int i = 1; i <= n; i++)
				for (int j = 1; j <= n; j++) {
					G[i][j] = ::max( G[i][j], min(G[i][k], G[k][j]) );
				}
	}
	
